# -*- coding: utf-8 -*-
# Copyright (C) 2020-2022 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from decimal import Decimal

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.gmpv214 import SeverityLevel


class GmpCreateNoteTestMixin:
    def test_create_note(self):
        self.gmp.create_note("foo", nvt_oid="oid1")

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "</create_note>"
        )

    def test_create_note_missing_text(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_note(None, "od1")

        with self.assertRaises(RequiredArgument):
            self.gmp.create_note("", "oid1")

    def test_create_note_missing_nvt_oid(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_note("foo", None)

        with self.assertRaises(RequiredArgument):
            self.gmp.create_note("foo", "")

    def test_create_note_with_hosts(self):
        self.gmp.create_note("foo", nvt_oid="oid1", hosts=[])

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "</create_note>"
        )

        self.gmp.create_note("foo", nvt_oid="oid1", hosts=["h1", "h2"])

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<hosts>h1,h2</hosts>"
            "</create_note>"
        )

    def test_create_note_with_port(self):
        self.gmp.create_note("foo", nvt_oid="oid1", port="666/tcp")

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<port>666/tcp</port>"
            "</create_note>"
        )

    def test_create_note_with_result_id(self):
        self.gmp.create_note("foo", nvt_oid="oid1", result_id="r1")

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            '<result id="r1"/>'
            "</create_note>"
        )

    def test_create_note_with_task_id(self):
        self.gmp.create_note("foo", nvt_oid="oid1", task_id="t1")

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            '<task id="t1"/>'
            "</create_note>"
        )

    def test_create_note_with_severity(self):
        self.gmp.create_note("foo", nvt_oid="oid1", severity="5.5")

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<severity>5.5</severity>"
            "</create_note>"
        )

        self.gmp.create_note("foo", nvt_oid="oid1", severity=5.5)

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<severity>5.5</severity>"
            "</create_note>"
        )

        self.gmp.create_note("foo", nvt_oid="oid1", severity=Decimal(5.5))

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<severity>5.5</severity>"
            "</create_note>"
        )

    def test_create_note_with_threat(self):
        self.gmp.create_note("foo", nvt_oid="oid1", threat=SeverityLevel.HIGH)

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "</create_note>"
        )

    def test_create_note_with_days_active(self):
        self.gmp.create_note("foo", nvt_oid="oid1", days_active=0)

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<active>0</active>"
            "</create_note>"
        )

        self.gmp.create_note("foo", nvt_oid="oid1", days_active=-1)

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<active>-1</active>"
            "</create_note>"
        )

        self.gmp.create_note("foo", nvt_oid="oid1", days_active=3600)

        self.connection.send.has_been_called_with(
            "<create_note>"
            "<text>foo</text>"
            '<nvt oid="oid1"/>'
            "<active>3600</active>"
            "</create_note>"
        )

    def test_create_note_with_invalid_port(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.create_note(text="foo", nvt_oid="oid1", port="123")

        with self.assertRaises(InvalidArgument):
            self.gmp.create_note(text="foo", nvt_oid="oid1", port="tcp/123")



# -*- coding: utf-8 -*-
# Copyright (C) 2020-2022 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import RequiredArgument


class GmpModifyPolicySetScannerPreferenceTestMixin:
    def test_modify_policy_set_scanner_pref(self):
        self.gmp.modify_policy_set_scanner_preference(
            policy_id="c1", name="foo"
        )

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<preference>"
            "<name>foo</name>"
            "</preference>"
            "</modify_config>"
        )

        self.gmp.modify_policy_set_scanner_preference("c1", "foo")

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<preference>"
            "<name>foo</name>"
            "</preference>"
            "</modify_config>"
        )

    def test_modify_policy_set_scanner_pref_with_value(self):
        self.gmp.modify_policy_set_scanner_preference("c1", "foo", value="bar")

        self.connection.send.has_been_called_with(
            '<modify_config config_id="c1">'
            "<preference>"
            "<name>foo</name>"
            "<value>YmFy</value>"
            "</preference>"
            "</modify_config>"
        )

    def test_modify_policy_scanner_pref_missing_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_scanner_preference(
                "c1", name=None, value="bar"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_scanner_preference(
                "c1", name="", value="bar"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_scanner_preference("c1", "", value="bar")

    def test_modify_policy_set_comment_missing_config_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_scanner_preference(
                policy_id=None, name="foo"
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_scanner_preference("", "foo")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_policy_set_scanner_preference(
                policy_id="", name="foo"
            )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from decimal import Decimal

from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
from gvm.protocols.gmpv208 import SeverityLevel


class GmpModifyOverrideTestMixin:
    def test_modify_override(self):
        self.gmp.modify_override(override_id="o1", text="foo")

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "</modify_override>"
        )

    def test_modify_override_missing_override_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_override(override_id=None, text="foo")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_override(override_id="", text="foo")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_override("", text="foo")

    def test_modify_override_missing_text(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_override(override_id="o1", text="")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_override(override_id="o1", text=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_override("o1", "")

    def test_modify_override_with_days_active(self):
        self.gmp.modify_override(override_id="o1", text="foo", days_active=0)

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<active>0</active>"
            "</modify_override>"
        )

        self.gmp.modify_override(override_id="o1", text="foo", days_active=-1)

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<active>-1</active>"
            "</modify_override>"
        )

        self.gmp.modify_override(override_id="o1", text="foo", days_active=600)

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<active>600</active>"
            "</modify_override>"
        )

    def test_modify_override_with_port(self):
        self.gmp.modify_override(override_id="o1", text="foo", port="123/udp")

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<port>123/udp</port>"
            "</modify_override>"
        )

    def test_modify_override_with_hosts(self):
        self.gmp.modify_override(override_id="o1", text="foo", hosts=["foo"])

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<hosts>foo</hosts>"
            "</modify_override>"
        )

        self.gmp.modify_override(
            override_id="o1", text="foo", hosts=["foo", "bar"]
        )

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<hosts>foo,bar</hosts>"
            "</modify_override>"
        )

    def test_modify_override_with_result_id(self):
        self.gmp.modify_override(override_id="o1", text="foo", result_id="r1")

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            '<result id="r1"/>'
            "</modify_override>"
        )

    def test_modify_override_with_task_id(self):
        self.gmp.modify_override(override_id="o1", text="foo", task_id="r1")

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            '<task id="r1"/>'
            "</modify_override>"
        )

    def test_modify_override_with_severity(self):
        self.gmp.modify_override(override_id="o1", text="foo", severity="5.5")

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<severity>5.5</severity>"
            "</modify_override>"
        )

        self.gmp.modify_override(override_id="o1", text="foo", severity=5.5)

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<severity>5.5</severity>"
            "</modify_override>"
        )

        self.gmp.modify_override(
            override_id="o1", text="foo", severity=Decimal(5.5)
        )

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<severity>5.5</severity>"
            "</modify_override>"
        )

    def test_modify_override_with_new_severity(self):
        self.gmp.modify_override(
            override_id="o1", text="foo", new_severity="5.5"
        )

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<new_severity>5.5</new_severity>"
            "</modify_override>"
        )

        self.gmp.modify_override(override_id="o1", text="foo", new_severity=5.5)

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<new_severity>5.5</new_severity>"
            "</modify_override>"
        )

        self.gmp.modify_override(
            override_id="o1", text="foo", new_severity=Decimal(5.5)
        )

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<new_severity>5.5</new_severity>"
            "</modify_override>"
        )

    def test_modify_override_with_threat(self):
        self.gmp.modify_override(
            override_id="o1", text="foo", threat=SeverityLevel.HIGH
        )

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<threat>High</threat>"
            "</modify_override>"
        )

    def test_modify_override_invalid_threat(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_override(override_id="o1", text="foo", threat="")

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_override(override_id="o1", text="foo", threat="foo")

    def test_modify_override_with_new_threat(self):
        self.gmp.modify_override(
            override_id="o1", text="foo", new_threat=SeverityLevel.HIGH
        )

        self.connection.send.has_been_called_with(
            '<modify_override override_id="o1">'
            "<text>foo</text>"
            "<new_threat>High</new_threat>"
            "</modify_override>"
        )

    def test_modify_override_invalid_new_threat(self):
        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_override(
                override_id="o1", text="foo", new_threat=""
            )

        with self.assertRaises(InvalidArgumentType):
            self.gmp.modify_override(
                override_id="o1", text="foo", new_threat="foo"
            )

    def test_modify_override_with_invalid_port(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_override(override_id="o1", text="foo", port="123")

        with self.assertRaises(InvalidArgument):
            self.gmp.modify_override(
                override_id="o1", text="foo", port="tcp/123"
            )



# -*- coding: utf-8 -*-
# Copyright (C) 2018-2022 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import RequiredArgument


class GmpAuthenticateTestMixin:
    def test_missing_username(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.authenticate(None, "foo")

        with self.assertRaises(RequiredArgument):
            self.gmp.authenticate("", "foo")

    def test_missing_password(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.authenticate("bar", None)

        with self.assertRaises(RequiredArgument):
            self.gmp.authenticate("bar", "")

    def test_authentication_success(self):
        self.assertFalse(self.gmp.is_authenticated())

        self.gmp.authenticate("foo", "bar")

        self.connection.send.has_been_called_with(
            "<authenticate>"
            "<credentials>"
            "<username>foo</username>"
            "<password>bar</password>"
            "</credentials>"
            "</authenticate>"
        )

        self.assertTrue(self.gmp.is_authenticated())

    def test_authentication_failure(self):
        self.connection.read.return_value(
            '<authentication_response status="400" status_text="Auth failed"/>'
        )

        self.assertFalse(self.gmp.is_authenticated())

        self.gmp.authenticate("foo", "bar")

        self.connection.send.has_been_called_with(
            "<authenticate>"
            "<credentials>"
            "<username>foo</username>"
            "<password>bar</password>"
            "</credentials>"
            "</authenticate>"
        )

        self.assertFalse(self.gmp.is_authenticated())
